@@ -19,6 +19,7 @@ public class ASTERReader extends DEMReader {
     }
 
     public String datasetName() {
+        if(useLegacy) return legacyDatasetName;
         return name;
     }
 
@@ -31,6 +32,7 @@ public class ASTERReader extends DEMReader {
     }
 
     public String formatstring() {
+        if(useLegacy) return legacyfilenameformat;
         return filenameformat;
     }
 
@@ -48,11 +50,16 @@ public class ASTERReader extends DEMReader {
         public String zipEntryName(String name){
         return name + "_dem.tif";
     }
-
+        public String copyright() {
+            return copyright ;
+        }
     private static final boolean downloadable = false;
     private static final int recordlength = 3601;
-    private static final String filenameformat = "ASTGTM_%1s%02d%1s%03d";
-    private static final String name = "Advanced Spaceborne Thermal Emission and Reflection Radiometer (ASTER)";
+    private static final String legacyfilenameformat = "ASTGTM_%1s%02d%1s%03d";
+    private static final String filenameformat = "ASTGTM2_%1s%02d%1s%03d";
+    private static final String name = "Advanced Spaceborne Thermal Emission and Reflection Radiometer (ASTER)  Version 2";
+    private static final String legacyDatasetName = "Advanced Spaceborne Thermal Emission and Reflection Radiometer (ASTER)";
+    private static final String copyright = "ASTER GDEM is a product of METI and NASA";
     private static final String extn = ".zip";
     private static final boolean littleendian = true;
     private static final int missingValue = -9999;
